camelot.camelot.model.authentication.PartyAddress

Package camelot :: Package camelot :: Package model :: Module authentication :: Class PartyAddress |
[hide private]
[frames] | no frames]

# Class PartyAddress

source code

Nested Classes | [hide private]
| Admin

Instance Methods | [hide private]
__unicode__(self) | source code
showMap(self) | source code

Class Variables | [hide private]
| party = `ManyToOne('Party', required= True, ondelete= 'cascade'`...``
| address = `ManyToOne('Address', required= True, ondelete= 'casc`...``
| from_date = `Field(Date(), default= datetime.date.today, requir`...``
| thru_date = `Field(Date(), default= end_of_times, required= Tru`...``
| comment = `Field(Unicode(256))`

Class Variable Details | [hide private]

  ### party Value:
      ManyToOne('Party', required= True, ondelete= 'cascade', onupdate= 'cas
      cade')

  ### address Value:
      ManyToOne('Address', required= True, ondelete= 'cascade', onupdate= 'c
      ascade')

  ### from_date Value:
      Field(Date(), default= datetime.date.today, required= True, index= Tru
      e)

  ### thru_date Value:
      Field(Date(), default= end_of_times, required= True, index= True)